timesignaturetools.MetricalHierarchyInventory
=============================================

.. abjad-lineage:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory

.. autoclass:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.append
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.count
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.extend
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.index
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.insert
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.pop
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.remove
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.reverse
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__add__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__delslice__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__ge__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__getslice__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__gt__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__imul__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__le__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__len__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__lt__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__mul__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__rmul__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__setitem__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory.__setslice__
   :noindex:
